elephant.spike\_train\_generation.compound\_poisson\_process
============================================================

.. currentmodule:: elephant.spike_train_generation

.. autofunction:: compound_poisson_process